#ifndef PROXY_H
#define PROXY_H

#include "api-driver/stricts-enable.h"
#include <boost/log/trivial.hpp>
#include <terminal_api/ControlProtoCInterface.h>


std::ostream& operator<<(std::ostream& out, CP_Result result);


namespace api_driver::proxy {
    class CpProxy {
    public:
        TSID sid;
        CP_Result lastCpError = OK;
        CpProxy();
        CpProxy(TSID s);

        /**
         * Вызывает процедуру подключения к CP_API. Бросает исключение, если не удалось подключиться.
         */
        void connect();

        /**
         * Процедура отключения от API, после ее вызова запрещается использовать CP_API
         */
        void disconnect();

        std::string getDmaDebug(const std::string& arg);
        void setDmaDebug(const std::string& arg, const std::string& value);

        std::string getNetwork(const std::string& param);
        void setNetwork(const std::string& param, const std::string& value);

        void getModState(modulator_state& dest);
        void getModSettings(modulator_settings& dest);
        void setModSettings(modulator_settings& dest);

        void getDemodState(demodulator_state& dest);
        void getDemodSettings(demodulator_settings& dest);
        void setDemodSettings(demodulator_settings& dest);

        void getDeviceState(device_state& dest);

#ifdef MODEM_IS_SCPC
        void getCincState(CinC_state& dest);
#endif

#ifdef API_OBJECT_DEBUG_METRICS_ENABLE
        void getDebugMetrics(debug_metrics& dest);
#endif

#ifdef MODEM_IS_TDMA
        void getUpdateStatus(progress_msg& dest);
#endif

        ~CpProxy();
    };
}


#endif //PROXY_H
